define(
//begin v1.x content
{
	"scientificFormat": "#E0",
	"infinity": "∞",
	"superscriptingExponent": "×",
	"list": ";",
	"percentSign": "%",
	"minusSign": "−",
	"decimalFormat-short": "000 bn",
	"nan": "NaN",
	"plusSign": "+",
	"currencyFormat": "#,##0.00 ¤",
	"perMille": "‰",
	"group": " ",
	"percentFormat": "#,##0 %",
	"decimalFormat-long": "000 biljoner",
	"decimalFormat": "#,##0.###",
	"currencyFormat-short": "000 bn ¤",
	"timeSeparator": ".",
	"decimal": ",",
	"exponential": "×10^"
}
//end v1.x content
);